@@ -6,10 +6,8 @@ class Authorize(object):
         self._responder = responder
 
     def __call__(self, req, resp, resource, params):
-        if resource.allowed is None:
-            return
-        
-        if not req.context.token:
+        print(resource.allowed)       
+        if not req.context.get("token"):
             return
         
         if not req.context.token.get("role") == 'admin':
